@@ -18,23 +18,28 @@
 
 import gtk, modules, tools
 
-from tools   import consts
-from modules import Module
+from tools   import consts, prefs
 from gettext import gettext as _
 
-
-class CtrlPanel(Module):
-    """
-        This module manages the control panel with the buttons and the slider
-    """
+MOD_INFO = ('Control Panel', 'Control Panel', '', [], True, False)
 
 
-    def __init__(self, wTree):
+class CtrlPanel(modules.Module):
+    """ This module manages the control panel with the buttons and the slider """
+
+    def __init__(self):
         """ Constructor """
-        Module.__init__(self)
+        modules.Module.__init__(self, (consts.MSG_EVT_STOPPED,        consts.MSG_EVT_PAUSED,      consts.MSG_EVT_UNPAUSED,
+                                       consts.MSG_EVT_TRACK_MOVED,    consts.MSG_EVT_NEW_TRACK,   consts.MSG_EVT_NEW_TRACKLIST,
+                                       consts.MSG_EVT_TRACK_POSITION, consts.MSG_EVT_APP_STARTED))
+
+
+    def onAppStarted(self):
+        """ Real initialization function, called when this module has been loaded """
         self.currTrackLength = 0
         self.sclBeingDragged = False
-        # Retrieve widgets
+        # Widgets
+        wTree             = prefs.getWidgetsTree()
         self.btnStop      = wTree.get_widget('btn-stop')
         self.btnPlay      = wTree.get_widget('btn-play')
         self.btnNext      = wTree.get_widget('btn-next')
@@ -42,20 +47,18 @@ class CtrlPanel(Module):
         self.sclSeek      = wTree.get_widget('scl-position')
         self.lblElapsed   = wTree.get_widget('lbl-elapsedTime')
         self.lblRemaining = wTree.get_widget('lbl-remainingTime')
+
         # Initial state
         self.onStopped()
         self.btnPlay.set_sensitive(False)
-        # Messages handled by this module
-        modules.register(self, [modules.MSG_EVT_STOPPED,   modules.MSG_EVT_PAUSED,        modules.MSG_EVT_UNPAUSED,      modules.MSG_EVT_TRACK_MOVED,
-                                modules.MSG_EVT_NEW_TRACK, modules.MSG_EVT_NEW_TRACKLIST, modules.MSG_EVT_TRACK_POSITION])
         # GTK handlers
-        self.btnStop.connect('clicked',      lambda widget: modules.postMsg(modules.MSG_CMD_STOP))
-        self.btnPlay.connect('clicked',      lambda widget: modules.postMsg(modules.MSG_CMD_TOGGLE_PAUSE))
-        self.btnNext.connect('clicked',      lambda widget: modules.postMsg(modules.MSG_CMD_NEXT))
-        self.btnPrev.connect('clicked',      lambda widget: modules.postMsg(modules.MSG_CMD_PREVIOUS))
-        self.sclSeek.connect('change-value', self.onSclChangeValue)
+        self.btnStop.connect('clicked',      lambda widget: modules.postMsg(consts.MSG_CMD_STOP))
+        self.btnNext.connect('clicked',      lambda widget: modules.postMsg(consts.MSG_CMD_NEXT))
+        self.btnPrev.connect('clicked',      lambda widget: modules.postMsg(consts.MSG_CMD_PREVIOUS))
+        self.btnPlay.connect('clicked',      lambda widget: modules.postMsg(consts.MSG_CMD_TOGGLE_PAUSE))
+        self.sclSeek.connect('change-value', self.onSeekChangeValue)
         # We need to keep the handler ID for this one to be able to disconnect it when needed
-        self.sclHandler = self.sclSeek.connect('value-changed', self.onSclValueChanged)
+        self.seekHandler   = self.sclSeek.connect('value-changed',   self.onSeekValueChanged)
 
 
     def onNewTrack(self, track):
@@ -92,9 +95,9 @@ class CtrlPanel(Module):
                 elapsedTime = self.currTrackLength
             self.lblRemaining.set_label(tools.sec2str(self.currTrackLength - elapsedTime))
             # Make sure the handler will not be called
-            self.sclSeek.disconnect(self.sclHandler)
+            self.sclSeek.disconnect(self.seekHandler)
             self.sclSeek.set_value(elapsedTime)
-            self.sclHandler = self.sclSeek.connect('value-changed', self.onSclValueChanged)
+            self.seekHandler = self.sclSeek.connect('value-changed', self.onSeekValueChanged)
 
 
     def onTrackMoved(self, hasPrevious, hasNext):
@@ -118,14 +121,14 @@ class CtrlPanel(Module):
     # --== GTK handlers ==--
 
 
-    def onSclValueChanged(self, range):
-        """ The user has moved the slider """
-        modules.postMsg(modules.MSG_CMD_SEEK, {'seconds': int(range.get_value())})
+    def onSeekValueChanged(self, range):
+        """ The user has moved the seek slider """
+        modules.postMsg(consts.MSG_CMD_SEEK, {'seconds': int(range.get_value())})
         self.sclBeingDragged = False
 
 
-    def onSclChangeValue(self, range, scroll, value):
-        """ The user is moving the slider """
+    def onSeekChangeValue(self, range, scroll, value):
+        """ The user is moving the seek slider """
         self.sclBeingDragged = True
 
         if value >= self.currTrackLength: value = self.currTrackLength
@@ -140,10 +143,11 @@ class CtrlPanel(Module):
 
     def handleMsg(self, msg, params):
         """ Handle message sent to this module """
-        if   msg == modules.MSG_EVT_PAUSED:         self.onPaused()
-        elif msg == modules.MSG_EVT_STOPPED:        self.onStopped()
-        elif msg == modules.MSG_EVT_UNPAUSED:       self.onUnpaused()
-        elif msg == modules.MSG_EVT_NEW_TRACK:      self.onNewTrack(params['track'])
-        elif msg == modules.MSG_EVT_TRACK_MOVED:    self.onTrackMoved(params['hasPrevious'], params['hasNext'])
-        elif msg == modules.MSG_EVT_NEW_TRACKLIST:  self.btnPlay.set_sensitive(len(params['files']) != 0)
-        elif msg == modules.MSG_EVT_TRACK_POSITION: self.onNewTrackPosition(params['seconds'])
+        if   msg == consts.MSG_EVT_PAUSED:         self.onPaused()
+        elif msg == consts.MSG_EVT_STOPPED:        self.onStopped()
+        elif msg == consts.MSG_EVT_UNPAUSED:       self.onUnpaused()
+        elif msg == consts.MSG_EVT_NEW_TRACK:      self.onNewTrack(params['track'])
+        elif msg == consts.MSG_EVT_APP_STARTED:    self.onAppStarted()
+        elif msg == consts.MSG_EVT_TRACK_MOVED:    self.onTrackMoved(params['hasPrevious'], params['hasNext'])
+        elif msg == consts.MSG_EVT_NEW_TRACKLIST:  self.btnPlay.set_sensitive(len(params['tracks']) != 0)
+        elif msg == consts.MSG_EVT_TRACK_POSITION: self.onNewTrackPosition(params['seconds'])
